@@ -6,7 +6,8 @@ Created on 05-Sep-2019
 
 WILLIAM_K_UL = -75
 WILLIAM_K_LL = -25
-fundamental_info_cols = ['EarningYield', 'FCFYield', 'ROC', 'BookToMkt', 'DivYield']
+fundamental_info_cols = ['EarningYield', 'FCFYield', 'ROC', 'BookToMkt', 'DivYield',
+                          'Yahoo 1 yr target', 'Intrinsic Value']
 
 STOCK_DETAIL_MODEL_KEY_MAP = {
   'Sector'                                          : 'sector',
